==> ssp-center-api-1.1.08-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqPrePayPage.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by Administrator on 2018/1/10.
 */
public class ReqPrePayPage extends ReqPageQuery implements Serializable {


    private Long    mediaId;

    private String  email;

    private Long    appId;

    private Long    prePayOrderId;

    private Integer prePayStatus;

    private String  startDate; //日期查询

    private String  endDate; //结束日期

    private String openAccount;//开户名称

    private Long  mediumId;//负责媒介

    private Integer newest;//默认全部：0 最新一条：1

    private Integer mediumAnomalyFlag; //媒介异常标识:1-异常 0-非异常

    private Integer mediaAnomalyFlag; //媒体异常标识:1-异常 0-非异常

    /**
     * 状态列表
     */
    private List<Integer> prePayStatusList;

    /**
     * 账号ID列表
     */
    private List<Long> mediaIds;

    /**
     * 截止日期之前
     */
    private String beforeDate;
    /**
     * 账户类型 1-直客 2-代理 3代理商
     */
    private Integer accountType;

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Integer getMediumAnomalyFlag() {
        return mediumAnomalyFlag;
    }

    public void setMediumAnomalyFlag(Integer mediumAnomalyFlag) {
        this.mediumAnomalyFlag = mediumAnomalyFlag;
    }

    public Integer getMediaAnomalyFlag() {
        return mediaAnomalyFlag;
    }

    public void setMediaAnomalyFlag(Integer mediaAnomalyFlag) {
        this.mediaAnomalyFlag = mediaAnomalyFlag;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getPrePayOrderId() {
        return prePayOrderId;
    }

    public void setPrePayOrderId(Long prePayOrderId) {
        this.prePayOrderId = prePayOrderId;
    }

    public Integer getPrePayStatus() {
        return prePayStatus;
    }

    public void setPrePayStatus(Integer prePayStatus) {
        this.prePayStatus = prePayStatus;
    }

    public String getOpenAccount() {
        return openAccount;
    }

    public void setOpenAccount(String openAccount) {
        this.openAccount = openAccount;
    }

    public Long getMediumId() {
        return mediumId;
    }

    public void setMediumId(Long mediumId) {
        this.mediumId = mediumId;
    }

    public Integer getNewest() {
        return newest;
    }

    public void setNewest(Integer newest) {
        this.newest = newest;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public List<Integer> getPrePayStatusList() {
        return prePayStatusList;
    }

    public void setPrePayStatusList(List<Integer> prePayStatusList) {
        this.prePayStatusList = prePayStatusList;
    }

    public List<Long> getMediaIds() {
        return mediaIds;
    }

    public void setMediaIds(List<Long> mediaIds) {
        this.mediaIds = mediaIds;
    }

    public String getBeforeDate() {
        return beforeDate;
    }

    public void setBeforeDate(String beforeDate) {
        this.beforeDate = beforeDate;
    }
}

==> ssp-center-api-1.2.88-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqPrePayPage.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by Administrator on 2018/1/10.
 */
public class ReqPrePayPage extends ReqPageQuery implements Serializable {


    private Long    mediaId;

    private String  email;

    private Long    appId;

    private Long    prePayOrderId;

    private Integer prePayStatus;

    private String  startDate; //日期查询

    private String  endDate; //结束日期

    private String openAccount;//开户名称

    private Long  mediumId;//负责媒介

    private Integer newest;//默认全部：0 最新一条：1

    private Integer mediumAnomalyFlag; //媒介异常标识:1-异常 0-非异常

    private Integer mediaAnomalyFlag; //媒体异常标识:1-异常 0-非异常

    /**
     * 状态列表
     */
    private List<Integer> prePayStatusList;

    /**
     * 账号ID列表
     */
    private List<Long> mediaIds;

    /**
     * 截止日期之前
     */
    private String beforeDate;
    /**
     * 账户类型 1-直客 2-代理 3代理商
     */
    private Integer accountType;

    private Integer prePayType;

    public Integer getPrePayType() {
        return prePayType;
    }

    public void setPrePayType(Integer prePayType) {
        this.prePayType = prePayType;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Integer getMediumAnomalyFlag() {
        return mediumAnomalyFlag;
    }

    public void setMediumAnomalyFlag(Integer mediumAnomalyFlag) {
        this.mediumAnomalyFlag = mediumAnomalyFlag;
    }

    public Integer getMediaAnomalyFlag() {
        return mediaAnomalyFlag;
    }

    public void setMediaAnomalyFlag(Integer mediaAnomalyFlag) {
        this.mediaAnomalyFlag = mediaAnomalyFlag;
    }

    public Long getMediaId() {
        return mediaId;
    }

    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getPrePayOrderId() {
        return prePayOrderId;
    }

    public void setPrePayOrderId(Long prePayOrderId) {
        this.prePayOrderId = prePayOrderId;
    }

    public Integer getPrePayStatus() {
        return prePayStatus;
    }

    public void setPrePayStatus(Integer prePayStatus) {
        this.prePayStatus = prePayStatus;
    }

    public String getOpenAccount() {
        return openAccount;
    }

    public void setOpenAccount(String openAccount) {
        this.openAccount = openAccount;
    }

    public Long getMediumId() {
        return mediumId;
    }

    public void setMediumId(Long mediumId) {
        this.mediumId = mediumId;
    }

    public Integer getNewest() {
        return newest;
    }

    public void setNewest(Integer newest) {
        this.newest = newest;
    }

    public String getStartDate() {
        return startDate;
    }

    public void setStartDate(String startDate) {
        this.startDate = startDate;
    }

    public String getEndDate() {
        return endDate;
    }

    public void setEndDate(String endDate) {
        this.endDate = endDate;
    }

    public List<Integer> getPrePayStatusList() {
        return prePayStatusList;
    }

    public void setPrePayStatusList(List<Integer> prePayStatusList) {
        this.prePayStatusList = prePayStatusList;
    }

    public List<Long> getMediaIds() {
        return mediaIds;
    }

    public void setMediaIds(List<Long> mediaIds) {
        this.mediaIds = mediaIds;
    }

    public String getBeforeDate() {
        return beforeDate;
    }

    public void setBeforeDate(String beforeDate) {
        this.beforeDate = beforeDate;
    }
}
